@@ -12,10 +12,20 @@
       id <- ifelse(id == TRUE, -1, 1)
       rval[,1] <- rval[,1] * id
       names(rval) <- c("deg", "min", "sec")
-      rval
       }
 
-   # If matrix is comprised of three columns, assume conversion FROM degrees, minutes, seconds to decimal degrees:
+   # If matrix is comprised of two columns, assume conversion is FROM degrees and decimal minutes TO decimal degrees:
+   else if(dim(dat)[2] == 2){
+      deg <- abs(dat[,1])
+      min <- dat[,2] / 60
+      rval <- as.data.frame(deg + min)
+      id <- dat[,1] < 0
+      id <- ifelse(id == TRUE, -1, 1)
+      rval <- rval * id
+      names(rval) <- "ddeg"
+      }
+
+   # If matrix is comprised of three columns, assume conversion FROM degrees, minutes, seconds TO decimal degrees:
    else if(dim(dat)[2] == 3){
       deg <- abs(dat[,1])
       min <- dat[,2] / 60
